#### General

Name
  {$ ctrl.node['name'] $}
Maintenance
  {$ ctrl.node['maintenance'] ? 'True' : 'False' $}
Maintenance Reason
  {$ ctrl.node['maintenance_reason'] $}
Inspection Started At
  {$ ctrl.node['inspection_started_at'] $}
Inspection Finished At
  {$ ctrl.node['inspection_finished_at'] $}
Reservation
  {$ ctrl.node['reservation'] $}
Console Enabled
  {$ ctrl.node['console_enabled'] ? 'True' : 'False' $}

#### Provisioning Status

Instance ID
  {$ ctrl.node['instance_uuid'] $}
Power State
  {$ ctrl.node['power_state'] $}
Target Power State
  {$ ctrl.node['target_power_state'] $}
Provision State
  {$ ctrl.node['provision_state'] $}
Target Provision State
  {$ ctrl.node['target_provision_state'] $}
Last Error
  {$ ctrl.node['last_error'] $}
Updated At
  {$ ctrl.node['updated_at'] $}